==> moodle-1.4.3-pgsql.tgz: moodle/lang/fi/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['calendar'] = 'Kalenteri';
$string['calendarheading'] = '$a kalenteri';
$string['clickhide'] = 'klikkaa piilottaaksesi';
$string['clickshow'] = 'klikkaa nyttksesi';
$string['confirmeventdelete'] = 'Haluatko varmasti poistaa tmn tapahtuman';
$string['courseevents'] = 'Kurssin tapahtumat';
$string['dayview'] = 'Pivnkym';
$string['daywithnoevents'] = 'Ei tapahtumia tlle pivlle';
$string['default'] = 'Oletus';
$string['deleteevent'] = 'Poista tapahtuma';
$string['detailedmonthview'] = 'Tarkennettu kuukausinkym';
$string['durationminutes'] = 'Kesto minuutteina';
$string['durationnone'] = 'Ilman kestoa';
$string['durationuntil'] = 'Pttymisaika';
$string['editevent'] = 'Muokkaa tapahtumaa';
$string['errorbeforecoursestart'] = 'Tapahtumaa ei voi asettaa alkavaksi ennen kurssin aloituspiv';
$string['errorinvaliddate'] = 'Pivmr virheellinen';
$string['errorinvalidminutes'] = 'Mrit kesto 1 ja 999 minuutin vlilt.';
$string['errorinvalidrepeats'] = 'Mrit tapahtumien mr 1 ja 99 vlill.';
$string['errornodescription'] = 'Tapahtuman kuvaus puuttuu';
$string['errornoeventname'] = 'Tapahtuman nimi puuttuu';
$string['eventdate'] = 'Pivmr';
$string['eventdescription'] = 'Tapahtuman kuvaus';
$string['eventduration'] = 'Kesto';
$string['eventendtime'] = 'Tapahtuman pttymisaika';
$string['eventinstanttime'] = 'Aika';
$string['eventkind'] = 'Tapahtuman tyyppi';
$string['eventname'] = 'Nimi';
$string['eventrepeat'] = 'Toistot';
$string['eventsfor'] = '$a tapahtumaa';
$string['eventstarttime'] = 'Tapahtuman alkamisaika';
$string['eventtime'] = 'Aika';
$string['eventview'] = 'Tapahtumankym';
$string['expired'] = 'Tapahtuma on jo mennyt';
$string['explain_lookahead'] = 'Tm oletusasetus mritt, kuinka monen pivn pss tulevaisuudessa tapahtuman pit olla, jotta se nytettisiin \"tulevana tapahtumana\". Tapahtumia, jotka alkavat myhemmin, ei nytet koskaan tulevien tapahtumien listassa. Huomaa, ett <strong>ei ole mitn takeita</strong> siit, ett kaikki tmn ajan sisll olevat tapahtumat nytettisiin tulevien listassa; mikli niit on paljon (enemmn kuin asetus \"Tulevien tapahtumien listan maksimikoko\", kaukaisimmat tulevista tapahtumista eivt ny listassa.';
$string['explain_maxevents'] = 'Tm asetus mritt tulevien tapahtumien listan maksimikoon. Mikli valitset thn suuren luvun, saattaa tulevien tapahtumien lista vied huomattavan paljon tilaa ruudultasi.';
$string['explain_startwday'] = 'Tm asetus mritt tavan, jolla kuukausittainen kalenteri nytetn. Kyt tt asettaaksesi nkymlle tavan, johon olet tottunut.';
$string['explain_timeformat'] = 'Voit nytt ajat joko 12 tai 24 tunnin muodossa. Jos valitset \"oletus\", valinta suoritetaan sivuston asetusten mukaisesti.';
$string['fri'] = 'Pe';
$string['friday'] = 'Perjantai';
$string['globalevents'] = 'Yhteiset tapahtumat';
$string['gotocalendar'] = 'Siirry kalenteriin';
$string['groupevents'] = 'Ryhmn tapahtumat';
$string['hidden'] = 'Piilotettu';
$string['manyevents'] = '$a tapahtumaa';
$string['mon'] = 'Ma';
$string['monday'] = 'Maanantai';
$string['monthlyview'] = 'Kuukausinkym';
$string['newevent'] = 'Uusi tapahtuma';
$string['noupcomingevents'] = 'Ei tulevia tapahtumia';
$string['oneevent'] = '1 tapahtuma';
$string['pref_lookahead'] = 'Tulevien tapahtumien tarkastelu';
$string['pref_maxevents'] = 'Tulevien tapahtumien listan maksimikoko';
$string['pref_startwday'] = 'Viikon ensimminen piv';
$string['pref_timeformat'] = 'Aikojen muoto';
$string['preferences'] = 'Asetukset';
$string['preferences_available'] = 'Henkilkohtaiset asetuksesi';
$string['repeatnone'] = 'Ei toistoja';
$string['repeatweeksl'] = 'Toista viikoittain';
$string['repeatweeksr'] = 'tapahtumat';
$string['sat'] = 'La';
$string['saturday'] = 'Lauantai';
$string['shown'] = 'nkyviss';
$string['spanningevents'] = 'Tapahtumia kynniss parhaillaan';
$string['sun'] = 'Su';
$string['sunday'] = 'Sunnuntai';
$string['thischarset'] = 'iso-8859-1';
$string['thisdirection'] = 'ltr';
$string['thislanguage'] = 'Suomi';
$string['thu'] = 'To';
$string['thursday'] = 'Torstai';
$string['timeformat_12'] = '12-tuntinen (AP/IP)';
$string['timeformat_24'] = '24-tuntinen';
$string['today'] = 'Tnn';
$string['tomorrow'] = 'Huomenna';
$string['tt_deleteevent'] = 'Poista tapahtuma';
$string['tt_editevent'] = 'Muokkaa tapahtumaa';
$string['tt_hidecourse'] = 'Kurssin tapahtumat nytetn (piiloita)';
$string['tt_hideglobal'] = 'Yleiset tapahtumat nytetn  (piiloita)';
$string['tt_hidegroups'] = 'Ryhmn tapahtumat nytetn  (piiloita)';
$string['tt_hideuser'] = 'Kyttjn tapahtumat nytetn  (piiloita)';
$string['tt_showcourse'] = 'Kurssin tapahtumat piilotettuna (nyt)';
$string['tt_showglobal'] = 'Yleiset tapahtumat piilotettuna (nyt)';
$string['tt_showgroups'] = 'Ryhmn tapahtumat piilotettuna (nyt)';
$string['tt_showuser'] = 'Kyttjn tapahtumat piilotettuna (nyt)';
$string['tue'] = 'Ti';
$string['tuesday'] = 'Tiistai';
$string['typecourse'] = 'Koko kurssille';
$string['typegroup'] = 'Ryhmlle';
$string['typesite'] = 'Koko sivustolle';
$string['typeuser'] = 'Oma tapahtuma';
$string['upcomingevents'] = 'Tulevat tapahtumat';
$string['userevents'] = 'Omat tapahtumat';
$string['wed'] = 'Ke';
$string['wednesday'] = 'Keskiviikko';
$string['yesterday'] = 'Eilen';

?>

==> moodle-1.5-pgsql.tgz: moodle/lang/fi/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.5 + (2005060201)


$string['calendar'] = 'Kalenteri';
$string['calendarheading'] = '$a kalenteri';
$string['clickhide'] = 'piilota';
$string['clickshow'] = 'nyt';
$string['confirmeventdelete'] = 'Haluatko varmasti poistaa tmn tapahtuman';
$string['courseevents'] = 'Kurssin tapahtumat';
$string['dayview'] = 'Pivnkym';
$string['daywithnoevents'] = 'Ei tapahtumia tlle pivlle';
$string['default'] = 'Oletus';
$string['deleteevent'] = 'Poista tapahtuma';
$string['detailedmonthview'] = 'Tarkennettu kuukausinkym';
$string['durationminutes'] = 'Kesto minuutteina';
$string['durationnone'] = 'Ilman kestoa';
$string['durationuntil'] = 'Pttymisaika';
$string['editevent'] = 'Muokkaa tapahtumaa';
$string['errorbeforecoursestart'] = 'Tapahtumaa ei voi asettaa alkavaksi ennen kurssin aloituspiv';
$string['errorinvaliddate'] = 'Pivmr virheellinen';
$string['errorinvalidminutes'] = 'Mrit kesto 1 ja 999 minuutin vlilt.';
$string['errorinvalidrepeats'] = 'Mrit tapahtumien mr 1 ja 99 vlill.';
$string['errornodescription'] = 'Tapahtuman kuvaus puuttuu';
$string['errornoeventname'] = 'Tapahtuman nimi puuttuu';
$string['eventdate'] = 'Pivmr';
$string['eventdescription'] = 'Tapahtuman kuvaus';
$string['eventduration'] = 'Kesto';
$string['eventendtime'] = 'Tapahtuman pttymisaika';
$string['eventinstanttime'] = 'kello';
$string['eventkind'] = 'Tapahtuman tyyppi';
$string['eventname'] = 'Nimi';
$string['eventrepeat'] = 'Toistot';
$string['eventsfor'] = '$a tapahtumat';
$string['eventstarttime'] = 'Tapahtuman alkamisaika';
$string['eventtime'] = 'kello';
$string['eventview'] = 'Tapahtumankym';
$string['expired'] = 'Tapahtuma on jo mennyt';
$string['explain_lookahead'] = 'Tm oletusasetus mritt, kuinka monen pivn pss tulevaisuudessa tapahtuman pit olla, jotta se nytettisiin \"tulevana tapahtumana\". Tapahtumia, jotka alkavat myhemmin, ei nytet koskaan tulevien tapahtumien listassa. Huomaa, ett <strong>ei ole mitn takeita</strong> siit, ett kaikki tmn ajan sisll olevat tapahtumat nytettisiin tulevien listassa; mikli niit on paljon (enemmn kuin asetus \"Tulevien tapahtumien listan maksimikoko\", kaukaisimmat tulevista tapahtumista eivt ny listassa.';
$string['explain_maxevents'] = 'Tm asetus mritt tulevien tapahtumien listan maksimikoon. Mikli valitset thn suuren luvun, saattaa tulevien tapahtumien lista vied huomattavan paljon tilaa ruudultasi.';
$string['explain_persistflt'] = 'Jos tm asetus on pll, Moodle muistaa kalenterista valitsemiesi tapahtumien piilotuksen ja nyttmisen asetukset mys kirjautumiskertojen vlill.';
$string['explain_startwday'] = 'Tm asetus mritt tavan, jolla kuukausittainen kalenteri nytetn. Kyt tt asettaaksesi nkymlle tavan, johon olet tottunut.';
$string['explain_timeformat'] = 'Voit nytt ajat joko 12 tai 24 tunnin muodossa. Jos valitset \"oletus\", valinta suoritetaan sivuston asetusten mukaisesti.';
$string['fri'] = 'pe';
$string['friday'] = 'perjantai';
$string['globalevents'] = 'Yhteiset tapahtumat';
$string['gotocalendar'] = 'Siirry kalenteriin';
$string['groupevents'] = 'Ryhmn tapahtumat';
$string['hidden'] = 'Piilotettu';
$string['manyevents'] = '$a tapahtumaa';
$string['mon'] = 'ma';
$string['monday'] = 'maanantai';
$string['monthlyview'] = 'Kuukausinkym';
$string['newevent'] = 'Uusi tapahtuma';
$string['noupcomingevents'] = 'Ei tulevia tapahtumia';
$string['oneevent'] = '1 tapahtuma';
$string['pref_lookahead'] = 'Tulevien tapahtumien tarkastelu';
$string['pref_maxevents'] = 'Tulevien tapahtumien listan maksimikoko';
$string['pref_persistflt'] = 'Tallenna tapahtumien piilotusvalinnat';
$string['pref_startwday'] = 'Viikon ensimminen piv';
$string['pref_timeformat'] = 'Kellonajan muoto';
$string['preferences'] = 'Asetukset';
$string['preferences_available'] = 'Henkilkohtaiset asetuksesi';
$string['repeateditall'] = 'Kaikki $a toistuvaa tapahtumaa';
$string['repeateditthis'] = 'Vain tm tapahtuma';
$string['repeatnone'] = 'Ei toistoja';
$string['repeatweeksl'] = 'Toista viikoittain';
$string['repeatweeksr'] = 'tapahtumaa';
$string['sat'] = 'la';
$string['saturday'] = 'lauantai';
$string['shown'] = 'nkyviss';
$string['spanningevents'] = 'Tapahtumia kynniss parhaillaan';
$string['sun'] = 'su';
$string['sunday'] = 'sunnuntai';
$string['thu'] = 'to';
$string['thursday'] = 'torstai';
$string['timeformat_12'] = '12-tuntinen (AP/IP)';
$string['timeformat_24'] = '24-tuntinen';
$string['today'] = 'tnn';
$string['tomorrow'] = 'huomenna';
$string['tt_deleteevent'] = 'Poista tapahtuma';
$string['tt_editevent'] = 'Muokkaa tapahtumaa';
$string['tt_hidecourse'] = 'Kurssin tapahtumat nytetn (piilota)';
$string['tt_hideglobal'] = 'Yleiset tapahtumat nytetn (piilota)';
$string['tt_hidegroups'] = 'Ryhmn tapahtumat nytetn (piilota)';
$string['tt_hideuser'] = 'Kyttjn tapahtumat nytetn (piilota)';
$string['tt_showcourse'] = 'Kurssin tapahtumat piilotettuna (nyt)';
$string['tt_showglobal'] = 'Yleiset tapahtumat piilotettuna (nyt)';
$string['tt_showgroups'] = 'Ryhmn tapahtumat piilotettuna (nyt)';
$string['tt_showuser'] = 'Kyttjn tapahtumat piilotettuna (nyt)';
$string['tue'] = 'ti';
$string['tuesday'] = 'tiistai';
$string['typecourse'] = 'koko kurssille';
$string['typegroup'] = 'ryhmlle';
$string['typesite'] = 'koko sivustolle';
$string['typeuser'] = 'oma tapahtuma';
$string['upcomingevents'] = 'Tulevat tapahtumat';
$string['userevents'] = 'Omat tapahtumat';
$string['wed'] = 'ke';
$string['wednesday'] = 'keskiviikko';
$string['yesterday'] = 'eilen';
$string['youcandeleteallrepeats'] = 'Tm papahtuma on yksi toistuvien tapahtumien joukosta. Voit poistaa vain tmn tapahtuman tai kaikki $a tapahtumaa kerralla.';

?>
